@@ -241,7 +241,7 @@ class AndroidSetTopBox(TestObjectBase):
         self.throwIfDisposed()
         return ScreenshotBMPCommand(self).execute(filename)    
     
-    def screenshotJPG(self, filename, quality):
+    def screenshotJPG(self, filename, quality = None):
         self.throwIfDisposed()
         return ScreenShotJPGCommand(self).execute(filename, quality)    
     
@@ -402,7 +402,7 @@ class AndroidSetTopBox(TestObjectBase):
         self.throwIfDisposed()
         return SaveRegionCommand(self).execute(filename)
     
-    def snapShot(self, filename, imageFormat, quality):
+    def snapShot(self, filename, imageFormat, quality  = None):
         self.throwIfDisposed()
         return SnapShotCommand(self).execute(filename, imageFormat, quality)    
 
@@ -410,7 +410,7 @@ class AndroidSetTopBox(TestObjectBase):
         self.throwIfDisposed()
         return SnapShotBMPCommand(self).execute(filename)
     
-    def snapShotJPG(self, filename, quality):
+    def snapShotJPG(self, filename, quality = None):
         self.throwIfDisposed()
         return SnapShotJPGCommand(self).execute(filename, quality)
     
@@ -446,10 +446,10 @@ class AndroidSetTopBox(TestObjectBase):
         self.throwIfDisposed()
         return WaitForPatternNoMatchCommand(self).execute(filename, minSimilarity, timeout, mode, x, y, width, height)
     
-    def WaitForSample(self, x, y, width, height, minSimilarity, timeout, tolerance, distanceMethod = None, maxDistance = None):
+    def waitForSample(self, x, y, width, height, minSimilarity, timeout, tolerance = None, distanceMethod = None, maxDistance = None):
         self.throwIfDisposed()
         return WaitForSampleCommand(self).execute(x, y, width, height, minSimilarity, timeout, tolerance, distanceMethod, maxDistance)
     
-    def WaitForSampleNoMatch(self, x, y, width, height, minSimilarity, timeout, tolerance, distanceMethod = None, maxDistance = None):
+    def waitForSampleNoMatch(self, x, y, width, height, minSimilarity, timeout, tolerance = None, distanceMethod = None, maxDistance = None):
         self.throwIfDisposed()
         return WaitForSampleNoMatchCommand(self).execute(x, y, width, height, minSimilarity, timeout, tolerance, distanceMethod, maxDistance)
\ No newline at end of file
